<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="Lang">
 	<xsl:import href="template.xsl"/>
  	<xsl:import href="templatedate.xsl"/>
  	<xsl:import href="docdetails_template.xsl"/>

  	<xsl:variable name="useTableBodyContainer" select="false()" />
 
  <!-- override templates to prevent them showing anything -->

  <xsl:template name="welcomeEtc" />

  <xsl:template name="headerUserActions"/>
  <xsl:template name="headerMenuBar"/>
  <xsl:template name="headerMenuScripts"/>
  
  <xsl:template name="isNameLink">
    <xsl:value-of select="false()"/>
  </xsl:template>
  
  <xsl:template name="bodycontent">
  
  <xsl:variable name="returnPage" select="/webcenter_page/returnurl"/>
   <xsl:choose>
  	<xsl:when test="no_attr_category_msg">
    		<div class="alert alert-info" role="alert">
    			<xsl:value-of select="Lang:getStr(&lk;,'PREVIEW_DOC_HAS_NO_ATTRS_CATEGORY')"/>
    		</div>
    		<div class="form-group">
	    		<label class="offset-label"></label>
	    		<div class="form-entry">
	    			<input type="button" name="Return" value="{Lang:getStr(&lk;,'RETURN')}" title="{Lang:getStr(&lk;,'RETURN')}"
	          			 onclick="returnButtonClicked('{$returnPage}');" class="btn btn-primary"/>
       			 </div>
    		</div>
    </xsl:when>
    <xsl:otherwise>
	<div data-init="pages/docdetailspreview/PreviewDashboard">
		<xsl:attribute name="data-docversionid"><xsl:value-of select="doc_version/@id"/></xsl:attribute>
		<xsl:attribute name="data-returnurl"><xsl:value-of select="$returnPage"/></xsl:attribute>
		<xsl:attribute name="data-chilisynctrimtext"><xsl:value-of select="/webcenter_page/CHILI_SYNC_TRIM_TEXT"/></xsl:attribute>	
	</div>
    </xsl:otherwise>
  </xsl:choose>
	
  </xsl:template>
  
   <!-- 
	 Display document header details 
  -->
  <xsl:template name="newDisplayDocDetailsHeader">
  	
  	<xsl:variable name="isCheckedOut" select="string-length(doc_version/document/checkout_owner_id)>0"/>
	<xsl:variable name="nameLink">
		<xsl:call-template name="isNameLink"/>		
	</xsl:variable>
	
	 <xsl:variable name="returnPage" select="/webcenter_page/returnurl"/>
	 <link rel="stylesheet" type="text/css" href="styles/legacy-tooltip.css"/>
	  
	<div class="page-header details-header with-menu documentHeader">
			<h1>
				<xsl:choose>
					<xsl:when test="count(project_list/project) = 1">
						<span>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'PDFSTAMP_PROJECT')"/></span>&nbsp;<xsl:value-of select="/webcenter_page/project_list/project/name" />&nbsp;&nbsp;
					</xsl:when>
					<xsl:otherwise>
						<span>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'PDFSTAMP_PROJECT')"/></span>&nbsp;
						<span class="legacy-tooltip">
							<!-- tooltip span -->
							<span style="text-align: left" class="legacy-tooltip-classic">
								<xsl:for-each select="/webcenter_page/project_list/project">
									<p class="darktext_darklink_11"><xsl:value-of select="name" /></p>
								</xsl:for-each>
							</span>
							<xsl:value-of select="Lang:getStr(&lk;,'CHILI_MULTIPLE_PROJECTS')"/>
						</span>
						&nbsp;&nbsp;
					</xsl:otherwise>
				</xsl:choose>
			
				<xsl:value-of select="Lang:getStr(&lk;,'DOCUMENT')"/>:&nbsp;
				<xsl:choose>
					<xsl:when test="$nameLink = 'true'">
						<a>
							<xsl:call-template name="docDetailsHref">
								<xsl:with-param name="docVerID" select="doc_version/@id"/>
							</xsl:call-template>
							<xsl:value-of select="doc_version/document/name"/>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="doc_version/document/name"/>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- Doc Version -->
					<span>
						&nbsp;&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'VERSION')"/>:&nbsp;
						<xsl:value-of select="doc_version/version_number"/>
					</span>
					
					<xsl:if test="number($versionRevision) > $noRevision">
						<span>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'REVISION')"/>&nbsp;<xsl:value-of select="$revisionLetter"/></span>
					</xsl:if>
					
				<!-- LOCKED -->
				<xsl:if test="/webcenter_page/locked_by_other_user = 1">
					&nbsp;&nbsp;<span class="red_medium_bold"><xsl:value-of select="Lang:getStr(&lk;,'CHILI_WARNING_LOCKED_DOC')"/></span>
				</xsl:if>
					
				<!-- Close Button -->
		    	   		 <i class="icon icon-normal icon-WCR_Close pull-right"  onclick ="javascript:returnButtonClicked('{$returnPage}');" />
			</h1>
		</div>
			
  </xsl:template>
  <!-- 
	 template that controls the inclusion of javascript functionality 
  -->
  <xsl:template name="scriptincs">
    <xsl:call-template name="DocDetailsJavaScript"/>  
    
     <script type="text/javascript">
      <xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;
      <!-- This function is called when Return button is clicked -->
   		 function returnButtonClicked(url, newWindow) {
			if (newWindow) {
		 	 window.open(url);
			} else {
			  window.location = url;          
			}
			return;
   		 }
     <xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
    </script>
  </xsl:template>
  
</xsl:stylesheet>